@@ -3,7 +3,7 @@ package Calendar::Indonesia::Holiday;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-03-09'; # DATE
 our $DIST = 'Calendar-Indonesia-Holiday'; # DIST
-our $VERSION = '0.338'; # VERSION
+our $VERSION = '0.339'; # VERSION
 
 use 5.010001;
 use strict;
@@ -1392,6 +1392,7 @@ _
         start_date => {
             summary => 'Starting date',
             schema  => 'str*',
+            pos => 0,
             description => <<'_',
 
 Defaults to start of current month. Either a string in the form of "YYYY-MM-DD",
@@ -1402,6 +1403,7 @@ _
         end_date => {
             summary => 'End date',
             schema  => 'str*',
+            pos => 1,
             description => <<'_',
 
 Defaults to end of current month. Either a string in the form of "YYYY-MM-DD",
@@ -1416,6 +1418,7 @@ _
         observe_joint_leaves => {
             summary => 'If set to 0, do not observe joint leave as holidays',
             schema  => ['bool' => {default => 1}],
+            cmdline_aliases => {j=>{}},
         },
     },
 };
@@ -1596,7 +1599,7 @@ Calendar::Indonesia::Holiday - List Indonesian public holidays
 
 =head1 VERSION
 
-This document describes version 0.338 of Calendar::Indonesia::Holiday (from Perl distribution Calendar-Indonesia-Holiday), released on 2021-03-09.
+This document describes version 0.339 of Calendar::Indonesia::Holiday (from Perl distribution Calendar-Indonesia-Holiday), released on 2021-03-09.
 
 =head1 SYNOPSIS
 
@@ -2419,6 +2422,10 @@ Some religious holidays, especially Vesakha, are not determined yet. Joint leave
 days are also usually decreed by the government in as late as October/November
 in the preceding year.
 
+=head2 How to calculate the difference of two dates in number of working days?
+
+Use L</count_idn_workdays>.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Calendar-Indonesia-Holiday>.
